@@ -16,7 +16,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.250';
+$VERSION = '3.300';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -244,7 +244,7 @@ sub get_parameters {
     my %args = (gcc_stlyle => $self->{gcc_style},);
     # Defines
     my @params = ();
-    foreach my $def (sort (keys %{$self->{defines}})) {
+    foreach my $def ($self->define_names_sorted) {
 	my $defvalue = $self->defvalue($def);
 	$defvalue = "=".($defvalue||"") if (defined $defvalue && $defvalue ne "");
 	if ($args{gcc_style}) {
@@ -430,6 +430,11 @@ sub map_directories {
 #######################################################################
 # Getopt functions
 
+sub define_names_sorted {
+    my $self = shift;
+    return (sort (keys %{$self->{defines}}));
+}
+
 sub defcmdline {
     my $self = shift;
     my $token = shift;
@@ -628,6 +633,10 @@ An optional third argument specifies parameters to the define, and a fourth
 argument if true indicates the define was set on the command line and
 should not be removed by `undefineall.
 
+=item $self->define_names_sorted
+
+Return sorted list of all define names that currently exist.
+
 =item $self->defparams ( $token )
 
 This method returns the parameter list of the define.  This will be defined,
