@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2000-2009 by Wilson Snyder.  This program is free software;
+// Copyright 2000-2010 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 //
@@ -29,22 +29,7 @@ int VFileLine::s_numErrors = 0;		///< Number of errors detected
 
 //============================================================================
 
-VFileLine* VFileLine::create(const string filename, int lineno) {
-    VFileLine* filelp = new VFileLine(true);
-    filelp->init(filename, lineno);
-    return filelp;
-}
-
-VFileLine* VFileLine::create(int lineno) {
-    return (this->create(this->filename(), lineno));
-}
-
-VFileLine* VFileLine::create_default() {
-    VFileLine* filelp = new VFileLine(true);
-    return filelp;
-}
-
-void VFileLine::init(const string filename, int lineno) {
+void VFileLine::init(const string& filename, int lineno) {
     m_filename = filename;
     m_lineno = lineno;
 }
@@ -58,12 +43,12 @@ const string VFileLine::filebasename () const {
     return name;
 }
 
-void VFileLine::fatal(const string msg) {
+void VFileLine::fatal(const string& msg) {
     error(msg);
     error("Fatal Error detected");
     abort();
 }
-void VFileLine::error(const string msg) {
+void VFileLine::error(const string& msg) {
     VFileLine::s_numErrors++;
     if (msg[msg.length()-1] != '\n') {
 	fprintf (stderr, "%%Error: %s", msg.c_str());
@@ -78,7 +63,13 @@ const char* VFileLine::itoa(int i) {
     return buf;
 }
 
-VFileLine* VFileLine::lineDirective(const char* textp) {
+string VFileLine::lineDirectiveStrg(int enterExit) const {
+    char numbuf[20]; sprintf(numbuf, "%d", lineno());
+    char levelbuf[20]; sprintf(levelbuf, "%d", enterExit);
+    return ((string)"`line "+numbuf+" \""+filename()+"\" "+levelbuf+"\n");
+}
+
+VFileLine* VFileLine::lineDirective(const char* textp, int& enterExitRef) {
     // Handle `line directive
     // Skip `line
     while (*textp && isspace(*textp)) textp++;
@@ -103,6 +94,12 @@ VFileLine* VFileLine::lineDirective(const char* textp) {
 	strfn = strfn.substr(0, textp-fn);
 	filename = strfn;
     }
+
+    // Grab level
+    while (*textp && (isspace(*textp) || *textp=='"')) textp++;
+    if (isdigit(*textp)) enterExitRef = atoi(textp);
+    else enterExitRef = 0;
+
     return create(filename,lineno);
 }
 
@@ -111,7 +108,7 @@ VFileLine* VFileLine::lineDirective(const char* textp) {
 
 ostream& operator<<(ostream& os, VFileLine* flp) {
     if (flp->filename()!="") {
-	os <<flp->cfilename()<<":"<<dec<<flp->lineno()<<": "<<hex;
+	os <<flp->filename()<<":"<<dec<<flp->lineno()<<": "<<hex;
     }
     return(os);
 }
